==> apache-superset-1.0.0-source.tar.gz: apache-superset-1.0.0rc4/superset-frontend/src/views/CRUD/alert/components/RecipientIcon.tsx <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import { styled, t } from '@superset-ui/core';
import React from 'react';
import { Tooltip } from 'src/common/components/Tooltip';
import Icon, { IconName } from 'src/components/Icon';
import { RecipientIconName } from '../types';

const StyledIcon = styled(Icon)`
  color: ${({ theme }) => theme.colors.grayscale.light1};
  margin-right: ${({ theme }) => theme.gridUnit * 2}px;
`;

export default function RecipientIcon({ type }: { type: string }) {
  const recipientIconConfig = {
    name: '',
    label: '',
  };
  switch (type) {
    case RecipientIconName.email:
      recipientIconConfig.name = 'email';
      recipientIconConfig.label = t(`${RecipientIconName.email}`);
      break;
    case RecipientIconName.slack:
      recipientIconConfig.name = 'slack';
      recipientIconConfig.label = t(`${RecipientIconName.slack}`);
      break;
    default:
      recipientIconConfig.name = '';
      recipientIconConfig.label = '';
  }
  return recipientIconConfig.name.length ? (
    <Tooltip title={recipientIconConfig.label} placement="bottom">
      <StyledIcon name={recipientIconConfig.name as IconName} />
    </Tooltip>
  ) : null;
}

==> apache-superset-1.4.2-source.tar.gz: apache-superset-1.4.2rc1/superset-frontend/src/views/CRUD/alert/components/RecipientIcon.tsx <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import { t, SupersetTheme, css } from '@superset-ui/core';
import React, { ReactElement } from 'react';
import { Tooltip } from 'src/components/Tooltip';
import Icons from 'src/components/Icons';
import { RecipientIconName } from '../types';

const StyledIcon = (theme: SupersetTheme) => css`
  color: ${theme.colors.grayscale.light1};
  margin-right: ${theme.gridUnit * 2}px;
`;

export default function RecipientIcon({ type }: { type: string }) {
  const recipientIconConfig: { icon: null | ReactElement; label: string } = {
    icon: null,
    label: '',
  };
  switch (type) {
    case RecipientIconName.email:
      recipientIconConfig.icon = <Icons.Email css={StyledIcon} />;
      recipientIconConfig.label = t(`${RecipientIconName.email}`);
      break;
    case RecipientIconName.slack:
      recipientIconConfig.icon = <Icons.Slack css={StyledIcon} />;
      recipientIconConfig.label = t(`${RecipientIconName.slack}`);
      break;
    default:
      recipientIconConfig.icon = null;
      recipientIconConfig.label = '';
  }
  return recipientIconConfig.icon ? (
    <Tooltip title={recipientIconConfig.label} placement="bottom">
      {recipientIconConfig.icon}
    </Tooltip>
  ) : null;
}
